<h1 align="center">
pylzss      
</h1>
<p align="center">
  <a href="https://github.com/m1stadev/pylzss/blob/master/LICENSE">
    <image src="https://img.shields.io/github/license/m1stadev/pylzss">
  </a>
  <a href="https://github.com/m1stadev/pylzss">
    <image src="https://tokei.rs/b1/github/m1stadev/pylzss?category=code&lang=python&style=flat">
  </a>
  <a href="https://github.com/m1stadev/pylzss/stargazers">
    <image src="https://img.shields.io/github/stars/m1stadev/pylzss">
  </a>
    <br>
</p>

<p align="center">
A Python library for decoding/encoding LZSS-compressed data.
</p>

<p align="center">
<i>This project is based on <a href="https://github.com/yyogo/pylzss">yyogo's pylzss</a>, I have only added CI.</i>
</p>

## Installation
- Install from [PyPI](https://pypi.org/p/pylzss):
    - ```python3 -m pip install pylzss```
- Local installation:
    - ```python3 -m pip install .```
